@@ -1,13 +1,14 @@
 from threading import Lock
 
+from constance import config
+from constance import signals
+
 from . import Backend
-from .. import signals, config
 
 
 class MemoryBackend(Backend):
-    """
-    Simple in-memory backend that should be mostly used for testing purposes
-    """
+    """Simple in-memory backend that should be mostly used for testing purposes."""
+
     _storage = {}
     _lock = Lock()
 
@@ -20,7 +21,7 @@ class MemoryBackend(Backend):
 
     def mget(self, keys):
         if not keys:
-            return
+            return None
         result = []
         with self._lock:
             for key in keys:
@@ -33,6 +34,4 @@ class MemoryBackend(Backend):
         with self._lock:
             old_value = self._storage.get(key)
             self._storage[key] = value
-            signals.config_updated.send(
-                sender=config, key=key, old_value=old_value, new_value=value
-            )
+            signals.config_updated.send(sender=config, key=key, old_value=old_value, new_value=value)
