@@ -12,19 +12,19 @@ def _migrate_from_old_table(apps, schema_editor) -> None:
     On new installations just ignore error that table does not exist.
     """
     connection = schema_editor.connection
-    quoted_string = ', '.join([connection.ops.quote_name(item) for item in ['id', 'key', 'value']])
-    old_table_name = 'constance_config'
+    quoted_string = ", ".join([connection.ops.quote_name(item) for item in ["id", "key", "value"]])
+    old_table_name = "constance_config"
     with connection.cursor() as cursor:
         if old_table_name not in connection.introspection.table_names():
-            logger.info('Old table does not exist, skipping')
+            logger.info("Old table does not exist, skipping")
             return
         cursor.execute(
-            f'INSERT INTO constance_constance ( {quoted_string} ) SELECT {quoted_string} FROM {old_table_name}',  # noqa: S608
+            f"INSERT INTO constance_constance ( {quoted_string} ) SELECT {quoted_string} FROM {old_table_name}",  # noqa: S608
             [],
         )
-        cursor.execute(f'DROP TABLE {old_table_name}', [])
+        cursor.execute(f"DROP TABLE {old_table_name}", [])
 
-    Constance = apps.get_model('constance', 'Constance')
+    Constance = apps.get_model("constance", "Constance")
     sequence_sql = connection.ops.sequence_reset_sql(no_style(), [Constance])
     with connection.cursor() as cursor:
         for sql in sequence_sql:
@@ -32,7 +32,7 @@ def _migrate_from_old_table(apps, schema_editor) -> None:
 
 
 class Migration(migrations.Migration):
-    dependencies = [('constance', '0001_initial')]
+    dependencies = [("constance", "0001_initial")]
 
     atomic = False
 
