@@ -15,7 +15,7 @@ logger = logging.getLogger(__name__)
 def is_already_migrated(value):
     try:
         data = json.loads(value)
-        if isinstance(data, dict) and set(data.keys()) == {'__type__', '__value__'}:
+        if isinstance(data, dict) and set(data.keys()) == {"__type__", "__value__"}:
             return True
     except (json.JSONDecodeError, TypeError, UnicodeDecodeError):
         return False
@@ -23,19 +23,22 @@ def is_already_migrated(value):
 
 
 def import_module_attr(path):
-    package, module = path.rsplit('.', 1)
+    package, module = path.rsplit(".", 1)
     return getattr(import_module(package), module)
 
 
 def migrate_pickled_data(apps, schema_editor) -> None:  # pragma: no cover
-    Constance = apps.get_model('constance', 'Constance')
+    Constance = apps.get_model("constance", "Constance")
 
     for constance in Constance.objects.exclude(value=None):
         if not is_already_migrated(constance.value):
             constance.value = dumps(pickle.loads(b64decode(constance.value.encode())))  # noqa: S301
-            constance.save(update_fields=['value'])
+            constance.save(update_fields=["value"])
 
-    if settings.BACKEND in ('constance.backends.redisd.RedisBackend', 'constance.backends.redisd.CachingRedisBackend'):
+    if settings.BACKEND in (
+        "constance.backends.redisd.RedisBackend",
+        "constance.backends.redisd.CachingRedisBackend",
+    ):
         import redis
 
         _prefix = settings.REDIS_PREFIX
@@ -49,7 +52,7 @@ def migrate_pickled_data(apps, schema_editor) -> None:  # pragma: no cover
                 _rd = redis.Redis(**settings.REDIS_CONNECTION)
         redis_migrated_data = {}
         for key in settings.CONFIG:
-            prefixed_key = f'{_prefix}{key}'
+            prefixed_key = f"{_prefix}{key}"
             value = _rd.get(prefixed_key)
             if value is not None and not is_already_migrated(value):
                 redis_migrated_data[prefixed_key] = dumps(pickle.loads(value))  # noqa: S301
@@ -58,7 +61,7 @@ def migrate_pickled_data(apps, schema_editor) -> None:  # pragma: no cover
 
 
 class Migration(migrations.Migration):
-    dependencies = [('constance', '0002_migrate_from_old_table')]
+    dependencies = [("constance", "0002_migrate_from_old_table")]
 
     operations = [
         migrations.RunPython(migrate_pickled_data),
