@@ -1,3 +1,3 @@
 from .unittest import override_config  # pragma: no cover
 
-__all__ = ['override_config']
+__all__ = ["override_config"]
