@@ -7,7 +7,7 @@ from tests.storage import StorageTestsMixin
 class TestDatabase(StorageTestsMixin, TestCase):
     def setUp(self):
         self.old_backend = settings.BACKEND
-        settings.BACKEND = 'constance.backends.database.DatabaseBackend'
+        settings.BACKEND = "constance.backends.database.DatabaseBackend"
         super().setUp()
 
     def test_database_queries(self):
