@@ -7,7 +7,7 @@ from tests.storage import StorageTestsMixin
 class TestMemory(StorageTestsMixin, TestCase):
     def setUp(self):
         self.old_backend = settings.BACKEND
-        settings.BACKEND = 'constance.backends.memory.MemoryBackend'
+        settings.BACKEND = "constance.backends.memory.MemoryBackend"
         super().setUp()
         self.config._backend._storage = {}
 
